package com.fs.doctor.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.doctor.mapper.DoctorBalanceLogMapper;
import com.fs.doctor.domain.DoctorBalanceLog;
import com.fs.doctor.service.IDoctorBalanceLogService;

/**
 * 医生积分变动记录Service业务层处理
 * 
 * @author fs
 * @date 2026-01-26
 */
@Service
public class DoctorBalanceLogServiceImpl implements IDoctorBalanceLogService 
{
    @Autowired
    private DoctorBalanceLogMapper doctorBalanceLogMapper;

    /**
     * 查询医生积分变动记录
     * 
     * @param id 医生积分变动记录主键
     * @return 医生积分变动记录
     */
    @Override
    public DoctorBalanceLog selectDoctorBalanceLogById(String id)
    {
        return doctorBalanceLogMapper.selectDoctorBalanceLogById(id);
    }

    /**
     * 查询医生积分变动记录列表
     * 
     * @param doctorBalanceLog 医生积分变动记录
     * @return 医生积分变动记录
     */
    @Override
    public List<DoctorBalanceLog> selectDoctorBalanceLogList(DoctorBalanceLog doctorBalanceLog)
    {
        return doctorBalanceLogMapper.selectDoctorBalanceLogList(doctorBalanceLog);
    }

    /**
     * 新增医生积分变动记录
     * 
     * @param doctorBalanceLog 医生积分变动记录
     * @return 结果
     */
    @Override
    public int insertDoctorBalanceLog(DoctorBalanceLog doctorBalanceLog)
    {
        return doctorBalanceLogMapper.insertDoctorBalanceLog(doctorBalanceLog);
    }

    /**
     * 修改医生积分变动记录
     * 
     * @param doctorBalanceLog 医生积分变动记录
     * @return 结果
     */
    @Override
    public int updateDoctorBalanceLog(DoctorBalanceLog doctorBalanceLog)
    {
        return doctorBalanceLogMapper.updateDoctorBalanceLog(doctorBalanceLog);
    }

    /**
     * 批量删除医生积分变动记录
     * 
     * @param ids 需要删除的医生积分变动记录主键
     * @return 结果
     */
    @Override
    public int deleteDoctorBalanceLogByIds(String[] ids)
    {
        return doctorBalanceLogMapper.deleteDoctorBalanceLogByIds(ids);
    }

    /**
     * 删除医生积分变动记录信息
     * 
     * @param id 医生积分变动记录主键
     * @return 结果
     */
    @Override
    public int deleteDoctorBalanceLogById(String id)
    {
        return doctorBalanceLogMapper.deleteDoctorBalanceLogById(id);
    }
}
